==> blazy-3.0.9.tar.gz: blazy/docs/CONTRIBUTION.md <==

***
## <a name="contribution"></a>SUBMITTING PATCHES OR ISSUES
Please use the provided issue template to help you explain better, and to help
us understand better your bug reports, or patches as needed.

* Avoid explaining everything in the title.
* Use body text for explanation purposes.
* If language is a barrier, use any available/ online translation tool.


### 1. SUBMITTING ISSUES
When submitting bug reports, please:

* be kind with proper reproduction, and enough details.
* mention library version, related-module version, if any, active theme, or
  anything which may help us identify issue better.
* ensure the library is loaded, not 404, and verify it can be viewed at browser.
* switch to stock (Responsive) Bartik for just in case it is your custom theme.
* switch to default formatters, image to Image, text to Default, etc.
* use matching or similar branches or tags for related modules.
* check out dups at project issues, your problem may be already addressed.
* consult descriptions on each form item.
* file it a support request, if unsure. We'll mark a bug a bug even if you
  file it under support requests.


### 2. SUBMITTING PATCHES
We consider a patch as help, they consider it a sale, so thank you in advanced!
In order for you to help, or buy, us successfully, please consider:

* communicating and filling out the body text with proper explanations, not in
  comments (unless for comment patches, of course).
  I've seen patches which broke a module, so explanation is a must.
  If you have no time to write it in the body text, please hold off till later!
* providing optional links to the change records, or docs, if any.
* providing links to docs is a must for coding standards issues.
  This also lets us, you and me, learn from the actual docs, not told by tools!
  We can just run `drupalcs ...`, but help is welcome, too, in case a miss.
* checking out the latest dev branch in case already resolved.
* providing reproduction steps for bug reports is a must. No repro, no bugs.

You must speak like human to human, and help us respect you, and your time.
Dumping patches with empty body text, or any disrespectful negative posts, will
be disregarded till the above is met.

### BUG REPORTS OR SUPPORT REQUESTS
A basic knowledge of Drupal site building is required. If you get stuck, please:

   * consult the provided READMEs via **/admin/help**.
   * consult descriptions on each form item.
   * consult the relevant guidelines from the supported modules.
   * search the project issue queues, your problem may be already addressed.

If you do have bug reports, we respect bugs, please:

   * provide steps to reproduce it, valid bugs must have consistent
     reproduction.
   * provide detailed info, a screenshot of the output and Blazy form, or words
     to identify it any better, library version, module version, active theme.
   * make sure that the bug is caused by the module.

For the Blazy library bug, please report it to:
  [Blazy library](https://github.com/dinbror/blazy)

You can create a fiddle to isolate the bug if reproduceable outside the module:
  [Fiddle](https://jsfiddle.net/)

For the support requests, a screenshot of the output and Blazy form are helpful.
Shortly, you should kindly help the maintainers with detailed info to help you.

### <a name="issues"></a> CONSTRUCTIVE VS. NON-CONSTRUCTIVE PROJECT ISSUES
1. We appreciate constructive, or at least normal/ minor, project issues:  
   + `Support/ Feature` requests,
   + `Bug` reports,
   + `Meta`, `Task` or `Plan`.  
2. If your issue were directed to this page, feel free to re-open it after:  
   + You prove we identified it incorrectly, and in such a case we are sorry.
   + You have redacted it accordingly, and or provide the required data.  

It is perfectly fine to be negative as long as backed by data, or info (form or
proof screenshots, benchmarks, docs, or anything else that add a value).
In fact, your name will be credited where credit's due with gratitude and
respect at CHANGELOG.txt or
[here](https://www.drupal.org/node/2663268/committers).

Offhanded negative posts without data are mere useless gossips we never welcome!

We are well aware, defects, bugs, flaws etc. are there as proven by bug fixes.
We believe constructive criticism, positive suggestions, corrections, patches,
even inspirational `Feature` or `Support` requests, will surely help us better.

We want to keep this project useful and friendly to all, we would truly
appreciate if you could kindly consider how to post respected and respectful
issues as outlined above so to have a mutual respect before submitting an issue.

In plain English, as the biker who sounded like talking about Newton Law III aka
karma, said: Treat me good, I'll treat you better...

Thank you for your positive consideration, cooperation, and kind contribution!

==> blazy-3.0.13.tar.gz: blazy/docs/CONTRIBUTION.md <==

***
## <a name="contribution"></a>SUBMITTING PATCHES OR ISSUES
Please use the provided issue template to help you explain better, and to help
us understand better your bug reports, or patches as needed.

* Avoid explaining everything in the title.
* Use body text for explanation purposes.
* If language is a barrier, use any available/ online translation tool.
* Be sure to type keywords of your would-be title in the provided Search box
  to avoid unnecessary dups. This would save your precious time not only for
  immediate solutions, but also from typing more useless words. Your problems
  might already be addressed. Only proceed if no existing issues are found.
* Do not abuse an issue as a vehicle for any strikes. Keep civil.


### 1. SUBMITTING ISSUES
When submitting bug reports, please:

* be kind with proper reproduction, and enough details.
* mention library version, related-module version, if any, active theme, or
  anything which may help us identify issue better.
* ensure the library is loaded, not 404, and verify it can be viewed at browser.
* switch to stock (Responsive) Bartik for just in case it is your custom theme.
* switch to default formatters, image to Image, text to Default, etc.
* use matching or similar branches or tags for related modules.
* check out dups at project issues, your problem may be already addressed.
* consult descriptions on each form item.
* file it a support request, if unsure. We'll mark a bug a bug even if you
  file it under support requests.


### 2. SUBMITTING PATCHES
We consider a patch as help, they consider it a sale, so thank you in advanced!
In order for you to help, or buy, us successfully, please consider:

* communicating and filling out the body text with proper explanations, not in
  comments (unless for comment patches, of course).
  I've seen patches which broke a module, so explanation is a must.
  If you have no time to write it in the body text, please hold off till later!
* providing optional links to the change records, or docs, if any.
* providing links to docs is a must for coding standards issues.
  This also lets us, you and me, learn from the actual docs, not told by tools!
  We can just run `drupalcs ...`, but help is welcome, too, in case a miss.
* checking out the latest dev branch in case already resolved.
* providing reproduction steps for bug reports is a must. No repro, no bugs.

You must speak like human to human, and help us respect you, and your time.
Dumping patches with empty body text, or any disrespectful negative posts, will
be disregarded till the above is met. We are not hungry for respects. We simply
do not welcome disrespects in respected project issues. It is the boundary.

### BUG REPORTS OR SUPPORT REQUESTS
A basic knowledge of Drupal site building is required. If you get stuck, please:

   * consult the provided READMEs via **/admin/help**.
   * consult descriptions on each form item.
   * consult the relevant guidelines from the supported modules.
   * search the project issue queues, your problem may be already addressed.

If you do have bug reports, we respect bugs, please:

   * provide steps to reproduce it, valid bugs must have consistent
     reproduction.
   * provide detailed info, a screenshot of the output and Blazy form, or words
     to identify it any better, library version, module version, active theme.
   * make sure that the bug is caused by the module.
   * do not game bugs, a waste of time, we'll know it, and close it.

For the Blazy library bug, please report it to:
  [Blazy library](https://github.com/dinbror/blazy)

You can create a fiddle to isolate the bug if reproduceable outside the module:
  [Fiddle](https://jsfiddle.net/)

For the support requests, a screenshot of the output and Blazy form are helpful.
Shortly, you should kindly help the maintainers with detailed info to help you.

### <a name="issues"></a> CONSTRUCTIVE VS. NON-CONSTRUCTIVE PROJECT ISSUES
1. We appreciate constructive, or at least normal/ minor, project issues:
   + `Support/ Feature` requests,
   + `Bug` reports,
   + `Meta`, `Task` or `Plan`.
2. If your issue were directed to this page, feel free to re-open it after:
   + You prove we identified it incorrectly, and in such a case we are sorry.
   + You have redacted it accordingly, and or provide the required data.

It is perfectly fine to be negative as long as backed by data, or info (form or
proof screenshots, benchmarks, docs, or anything else that add a value).
In fact, your name will be credited where credit's due with gratitude and
respect at CHANGELOG.txt or
[here](https://www.drupal.org/node/2663268/committers).

Offhanded toxic posts without data are mere useless gossips we never welcome!

We are well aware, defects, bugs, flaws etc. are there as proven by bug fixes.
We believe constructive criticism, positive suggestions, corrections, patches,
even inspirational `Feature` or `Support` requests, will surely help us better.

We want to keep this project useful and friendly to all, we would truly
appreciate if you could kindly consider how to post respected and respectful
issues as outlined above so to have a mutual respect before submitting an issue.

In plain English, as the biker who sounded like talking about Newton Law III aka
karma, said: Treat me good, I'll treat you better...

Thank you for your positive consideration, cooperation, and kind contribution!
